// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_RN_IDENTICAL_LOW_REGISTERS_IN_IT_BLOCK_MVN_T32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_RN_IDENTICAL_LOW_REGISTERS_IN_IT_BLOCK_MVN_T32_H_

const byte kInstruction_mvn_eq_r0_r0[] = {
  0x08, 0xbf, 0xc0, 0x43 // It eq; mvn eq r0 r0
};
const byte kInstruction_mvn_eq_r1_r1[] = {
  0x08, 0xbf, 0xc9, 0x43 // It eq; mvn eq r1 r1
};
const byte kInstruction_mvn_eq_r2_r2[] = {
  0x08, 0xbf, 0xd2, 0x43 // It eq; mvn eq r2 r2
};
const byte kInstruction_mvn_eq_r3_r3[] = {
  0x08, 0xbf, 0xdb, 0x43 // It eq; mvn eq r3 r3
};
const byte kInstruction_mvn_eq_r4_r4[] = {
  0x08, 0xbf, 0xe4, 0x43 // It eq; mvn eq r4 r4
};
const byte kInstruction_mvn_eq_r5_r5[] = {
  0x08, 0xbf, 0xed, 0x43 // It eq; mvn eq r5 r5
};
const byte kInstruction_mvn_eq_r6_r6[] = {
  0x08, 0xbf, 0xf6, 0x43 // It eq; mvn eq r6 r6
};
const byte kInstruction_mvn_eq_r7_r7[] = {
  0x08, 0xbf, 0xff, 0x43 // It eq; mvn eq r7 r7
};
const byte kInstruction_mvn_ne_r0_r0[] = {
  0x18, 0xbf, 0xc0, 0x43 // It ne; mvn ne r0 r0
};
const byte kInstruction_mvn_ne_r1_r1[] = {
  0x18, 0xbf, 0xc9, 0x43 // It ne; mvn ne r1 r1
};
const byte kInstruction_mvn_ne_r2_r2[] = {
  0x18, 0xbf, 0xd2, 0x43 // It ne; mvn ne r2 r2
};
const byte kInstruction_mvn_ne_r3_r3[] = {
  0x18, 0xbf, 0xdb, 0x43 // It ne; mvn ne r3 r3
};
const byte kInstruction_mvn_ne_r4_r4[] = {
  0x18, 0xbf, 0xe4, 0x43 // It ne; mvn ne r4 r4
};
const byte kInstruction_mvn_ne_r5_r5[] = {
  0x18, 0xbf, 0xed, 0x43 // It ne; mvn ne r5 r5
};
const byte kInstruction_mvn_ne_r6_r6[] = {
  0x18, 0xbf, 0xf6, 0x43 // It ne; mvn ne r6 r6
};
const byte kInstruction_mvn_ne_r7_r7[] = {
  0x18, 0xbf, 0xff, 0x43 // It ne; mvn ne r7 r7
};
const byte kInstruction_mvn_cs_r0_r0[] = {
  0x28, 0xbf, 0xc0, 0x43 // It cs; mvn cs r0 r0
};
const byte kInstruction_mvn_cs_r1_r1[] = {
  0x28, 0xbf, 0xc9, 0x43 // It cs; mvn cs r1 r1
};
const byte kInstruction_mvn_cs_r2_r2[] = {
  0x28, 0xbf, 0xd2, 0x43 // It cs; mvn cs r2 r2
};
const byte kInstruction_mvn_cs_r3_r3[] = {
  0x28, 0xbf, 0xdb, 0x43 // It cs; mvn cs r3 r3
};
const byte kInstruction_mvn_cs_r4_r4[] = {
  0x28, 0xbf, 0xe4, 0x43 // It cs; mvn cs r4 r4
};
const byte kInstruction_mvn_cs_r5_r5[] = {
  0x28, 0xbf, 0xed, 0x43 // It cs; mvn cs r5 r5
};
const byte kInstruction_mvn_cs_r6_r6[] = {
  0x28, 0xbf, 0xf6, 0x43 // It cs; mvn cs r6 r6
};
const byte kInstruction_mvn_cs_r7_r7[] = {
  0x28, 0xbf, 0xff, 0x43 // It cs; mvn cs r7 r7
};
const byte kInstruction_mvn_cc_r0_r0[] = {
  0x38, 0xbf, 0xc0, 0x43 // It cc; mvn cc r0 r0
};
const byte kInstruction_mvn_cc_r1_r1[] = {
  0x38, 0xbf, 0xc9, 0x43 // It cc; mvn cc r1 r1
};
const byte kInstruction_mvn_cc_r2_r2[] = {
  0x38, 0xbf, 0xd2, 0x43 // It cc; mvn cc r2 r2
};
const byte kInstruction_mvn_cc_r3_r3[] = {
  0x38, 0xbf, 0xdb, 0x43 // It cc; mvn cc r3 r3
};
const byte kInstruction_mvn_cc_r4_r4[] = {
  0x38, 0xbf, 0xe4, 0x43 // It cc; mvn cc r4 r4
};
const byte kInstruction_mvn_cc_r5_r5[] = {
  0x38, 0xbf, 0xed, 0x43 // It cc; mvn cc r5 r5
};
const byte kInstruction_mvn_cc_r6_r6[] = {
  0x38, 0xbf, 0xf6, 0x43 // It cc; mvn cc r6 r6
};
const byte kInstruction_mvn_cc_r7_r7[] = {
  0x38, 0xbf, 0xff, 0x43 // It cc; mvn cc r7 r7
};
const byte kInstruction_mvn_mi_r0_r0[] = {
  0x48, 0xbf, 0xc0, 0x43 // It mi; mvn mi r0 r0
};
const byte kInstruction_mvn_mi_r1_r1[] = {
  0x48, 0xbf, 0xc9, 0x43 // It mi; mvn mi r1 r1
};
const byte kInstruction_mvn_mi_r2_r2[] = {
  0x48, 0xbf, 0xd2, 0x43 // It mi; mvn mi r2 r2
};
const byte kInstruction_mvn_mi_r3_r3[] = {
  0x48, 0xbf, 0xdb, 0x43 // It mi; mvn mi r3 r3
};
const byte kInstruction_mvn_mi_r4_r4[] = {
  0x48, 0xbf, 0xe4, 0x43 // It mi; mvn mi r4 r4
};
const byte kInstruction_mvn_mi_r5_r5[] = {
  0x48, 0xbf, 0xed, 0x43 // It mi; mvn mi r5 r5
};
const byte kInstruction_mvn_mi_r6_r6[] = {
  0x48, 0xbf, 0xf6, 0x43 // It mi; mvn mi r6 r6
};
const byte kInstruction_mvn_mi_r7_r7[] = {
  0x48, 0xbf, 0xff, 0x43 // It mi; mvn mi r7 r7
};
const byte kInstruction_mvn_pl_r0_r0[] = {
  0x58, 0xbf, 0xc0, 0x43 // It pl; mvn pl r0 r0
};
const byte kInstruction_mvn_pl_r1_r1[] = {
  0x58, 0xbf, 0xc9, 0x43 // It pl; mvn pl r1 r1
};
const byte kInstruction_mvn_pl_r2_r2[] = {
  0x58, 0xbf, 0xd2, 0x43 // It pl; mvn pl r2 r2
};
const byte kInstruction_mvn_pl_r3_r3[] = {
  0x58, 0xbf, 0xdb, 0x43 // It pl; mvn pl r3 r3
};
const byte kInstruction_mvn_pl_r4_r4[] = {
  0x58, 0xbf, 0xe4, 0x43 // It pl; mvn pl r4 r4
};
const byte kInstruction_mvn_pl_r5_r5[] = {
  0x58, 0xbf, 0xed, 0x43 // It pl; mvn pl r5 r5
};
const byte kInstruction_mvn_pl_r6_r6[] = {
  0x58, 0xbf, 0xf6, 0x43 // It pl; mvn pl r6 r6
};
const byte kInstruction_mvn_pl_r7_r7[] = {
  0x58, 0xbf, 0xff, 0x43 // It pl; mvn pl r7 r7
};
const byte kInstruction_mvn_vs_r0_r0[] = {
  0x68, 0xbf, 0xc0, 0x43 // It vs; mvn vs r0 r0
};
const byte kInstruction_mvn_vs_r1_r1[] = {
  0x68, 0xbf, 0xc9, 0x43 // It vs; mvn vs r1 r1
};
const byte kInstruction_mvn_vs_r2_r2[] = {
  0x68, 0xbf, 0xd2, 0x43 // It vs; mvn vs r2 r2
};
const byte kInstruction_mvn_vs_r3_r3[] = {
  0x68, 0xbf, 0xdb, 0x43 // It vs; mvn vs r3 r3
};
const byte kInstruction_mvn_vs_r4_r4[] = {
  0x68, 0xbf, 0xe4, 0x43 // It vs; mvn vs r4 r4
};
const byte kInstruction_mvn_vs_r5_r5[] = {
  0x68, 0xbf, 0xed, 0x43 // It vs; mvn vs r5 r5
};
const byte kInstruction_mvn_vs_r6_r6[] = {
  0x68, 0xbf, 0xf6, 0x43 // It vs; mvn vs r6 r6
};
const byte kInstruction_mvn_vs_r7_r7[] = {
  0x68, 0xbf, 0xff, 0x43 // It vs; mvn vs r7 r7
};
const byte kInstruction_mvn_vc_r0_r0[] = {
  0x78, 0xbf, 0xc0, 0x43 // It vc; mvn vc r0 r0
};
const byte kInstruction_mvn_vc_r1_r1[] = {
  0x78, 0xbf, 0xc9, 0x43 // It vc; mvn vc r1 r1
};
const byte kInstruction_mvn_vc_r2_r2[] = {
  0x78, 0xbf, 0xd2, 0x43 // It vc; mvn vc r2 r2
};
const byte kInstruction_mvn_vc_r3_r3[] = {
  0x78, 0xbf, 0xdb, 0x43 // It vc; mvn vc r3 r3
};
const byte kInstruction_mvn_vc_r4_r4[] = {
  0x78, 0xbf, 0xe4, 0x43 // It vc; mvn vc r4 r4
};
const byte kInstruction_mvn_vc_r5_r5[] = {
  0x78, 0xbf, 0xed, 0x43 // It vc; mvn vc r5 r5
};
const byte kInstruction_mvn_vc_r6_r6[] = {
  0x78, 0xbf, 0xf6, 0x43 // It vc; mvn vc r6 r6
};
const byte kInstruction_mvn_vc_r7_r7[] = {
  0x78, 0xbf, 0xff, 0x43 // It vc; mvn vc r7 r7
};
const byte kInstruction_mvn_hi_r0_r0[] = {
  0x88, 0xbf, 0xc0, 0x43 // It hi; mvn hi r0 r0
};
const byte kInstruction_mvn_hi_r1_r1[] = {
  0x88, 0xbf, 0xc9, 0x43 // It hi; mvn hi r1 r1
};
const byte kInstruction_mvn_hi_r2_r2[] = {
  0x88, 0xbf, 0xd2, 0x43 // It hi; mvn hi r2 r2
};
const byte kInstruction_mvn_hi_r3_r3[] = {
  0x88, 0xbf, 0xdb, 0x43 // It hi; mvn hi r3 r3
};
const byte kInstruction_mvn_hi_r4_r4[] = {
  0x88, 0xbf, 0xe4, 0x43 // It hi; mvn hi r4 r4
};
const byte kInstruction_mvn_hi_r5_r5[] = {
  0x88, 0xbf, 0xed, 0x43 // It hi; mvn hi r5 r5
};
const byte kInstruction_mvn_hi_r6_r6[] = {
  0x88, 0xbf, 0xf6, 0x43 // It hi; mvn hi r6 r6
};
const byte kInstruction_mvn_hi_r7_r7[] = {
  0x88, 0xbf, 0xff, 0x43 // It hi; mvn hi r7 r7
};
const byte kInstruction_mvn_ls_r0_r0[] = {
  0x98, 0xbf, 0xc0, 0x43 // It ls; mvn ls r0 r0
};
const byte kInstruction_mvn_ls_r1_r1[] = {
  0x98, 0xbf, 0xc9, 0x43 // It ls; mvn ls r1 r1
};
const byte kInstruction_mvn_ls_r2_r2[] = {
  0x98, 0xbf, 0xd2, 0x43 // It ls; mvn ls r2 r2
};
const byte kInstruction_mvn_ls_r3_r3[] = {
  0x98, 0xbf, 0xdb, 0x43 // It ls; mvn ls r3 r3
};
const byte kInstruction_mvn_ls_r4_r4[] = {
  0x98, 0xbf, 0xe4, 0x43 // It ls; mvn ls r4 r4
};
const byte kInstruction_mvn_ls_r5_r5[] = {
  0x98, 0xbf, 0xed, 0x43 // It ls; mvn ls r5 r5
};
const byte kInstruction_mvn_ls_r6_r6[] = {
  0x98, 0xbf, 0xf6, 0x43 // It ls; mvn ls r6 r6
};
const byte kInstruction_mvn_ls_r7_r7[] = {
  0x98, 0xbf, 0xff, 0x43 // It ls; mvn ls r7 r7
};
const byte kInstruction_mvn_ge_r0_r0[] = {
  0xa8, 0xbf, 0xc0, 0x43 // It ge; mvn ge r0 r0
};
const byte kInstruction_mvn_ge_r1_r1[] = {
  0xa8, 0xbf, 0xc9, 0x43 // It ge; mvn ge r1 r1
};
const byte kInstruction_mvn_ge_r2_r2[] = {
  0xa8, 0xbf, 0xd2, 0x43 // It ge; mvn ge r2 r2
};
const byte kInstruction_mvn_ge_r3_r3[] = {
  0xa8, 0xbf, 0xdb, 0x43 // It ge; mvn ge r3 r3
};
const byte kInstruction_mvn_ge_r4_r4[] = {
  0xa8, 0xbf, 0xe4, 0x43 // It ge; mvn ge r4 r4
};
const byte kInstruction_mvn_ge_r5_r5[] = {
  0xa8, 0xbf, 0xed, 0x43 // It ge; mvn ge r5 r5
};
const byte kInstruction_mvn_ge_r6_r6[] = {
  0xa8, 0xbf, 0xf6, 0x43 // It ge; mvn ge r6 r6
};
const byte kInstruction_mvn_ge_r7_r7[] = {
  0xa8, 0xbf, 0xff, 0x43 // It ge; mvn ge r7 r7
};
const byte kInstruction_mvn_lt_r0_r0[] = {
  0xb8, 0xbf, 0xc0, 0x43 // It lt; mvn lt r0 r0
};
const byte kInstruction_mvn_lt_r1_r1[] = {
  0xb8, 0xbf, 0xc9, 0x43 // It lt; mvn lt r1 r1
};
const byte kInstruction_mvn_lt_r2_r2[] = {
  0xb8, 0xbf, 0xd2, 0x43 // It lt; mvn lt r2 r2
};
const byte kInstruction_mvn_lt_r3_r3[] = {
  0xb8, 0xbf, 0xdb, 0x43 // It lt; mvn lt r3 r3
};
const byte kInstruction_mvn_lt_r4_r4[] = {
  0xb8, 0xbf, 0xe4, 0x43 // It lt; mvn lt r4 r4
};
const byte kInstruction_mvn_lt_r5_r5[] = {
  0xb8, 0xbf, 0xed, 0x43 // It lt; mvn lt r5 r5
};
const byte kInstruction_mvn_lt_r6_r6[] = {
  0xb8, 0xbf, 0xf6, 0x43 // It lt; mvn lt r6 r6
};
const byte kInstruction_mvn_lt_r7_r7[] = {
  0xb8, 0xbf, 0xff, 0x43 // It lt; mvn lt r7 r7
};
const byte kInstruction_mvn_gt_r0_r0[] = {
  0xc8, 0xbf, 0xc0, 0x43 // It gt; mvn gt r0 r0
};
const byte kInstruction_mvn_gt_r1_r1[] = {
  0xc8, 0xbf, 0xc9, 0x43 // It gt; mvn gt r1 r1
};
const byte kInstruction_mvn_gt_r2_r2[] = {
  0xc8, 0xbf, 0xd2, 0x43 // It gt; mvn gt r2 r2
};
const byte kInstruction_mvn_gt_r3_r3[] = {
  0xc8, 0xbf, 0xdb, 0x43 // It gt; mvn gt r3 r3
};
const byte kInstruction_mvn_gt_r4_r4[] = {
  0xc8, 0xbf, 0xe4, 0x43 // It gt; mvn gt r4 r4
};
const byte kInstruction_mvn_gt_r5_r5[] = {
  0xc8, 0xbf, 0xed, 0x43 // It gt; mvn gt r5 r5
};
const byte kInstruction_mvn_gt_r6_r6[] = {
  0xc8, 0xbf, 0xf6, 0x43 // It gt; mvn gt r6 r6
};
const byte kInstruction_mvn_gt_r7_r7[] = {
  0xc8, 0xbf, 0xff, 0x43 // It gt; mvn gt r7 r7
};
const byte kInstruction_mvn_le_r0_r0[] = {
  0xd8, 0xbf, 0xc0, 0x43 // It le; mvn le r0 r0
};
const byte kInstruction_mvn_le_r1_r1[] = {
  0xd8, 0xbf, 0xc9, 0x43 // It le; mvn le r1 r1
};
const byte kInstruction_mvn_le_r2_r2[] = {
  0xd8, 0xbf, 0xd2, 0x43 // It le; mvn le r2 r2
};
const byte kInstruction_mvn_le_r3_r3[] = {
  0xd8, 0xbf, 0xdb, 0x43 // It le; mvn le r3 r3
};
const byte kInstruction_mvn_le_r4_r4[] = {
  0xd8, 0xbf, 0xe4, 0x43 // It le; mvn le r4 r4
};
const byte kInstruction_mvn_le_r5_r5[] = {
  0xd8, 0xbf, 0xed, 0x43 // It le; mvn le r5 r5
};
const byte kInstruction_mvn_le_r6_r6[] = {
  0xd8, 0xbf, 0xf6, 0x43 // It le; mvn le r6 r6
};
const byte kInstruction_mvn_le_r7_r7[] = {
  0xd8, 0xbf, 0xff, 0x43 // It le; mvn le r7 r7
};
const TestResult kReferencemvn[] = {
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r0_r0),
    kInstruction_mvn_eq_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r1_r1),
    kInstruction_mvn_eq_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r2_r2),
    kInstruction_mvn_eq_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r3_r3),
    kInstruction_mvn_eq_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r4_r4),
    kInstruction_mvn_eq_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r5_r5),
    kInstruction_mvn_eq_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r6_r6),
    kInstruction_mvn_eq_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_eq_r7_r7),
    kInstruction_mvn_eq_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r0_r0),
    kInstruction_mvn_ne_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r1_r1),
    kInstruction_mvn_ne_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r2_r2),
    kInstruction_mvn_ne_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r3_r3),
    kInstruction_mvn_ne_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r4_r4),
    kInstruction_mvn_ne_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r5_r5),
    kInstruction_mvn_ne_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r6_r6),
    kInstruction_mvn_ne_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ne_r7_r7),
    kInstruction_mvn_ne_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r0_r0),
    kInstruction_mvn_cs_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r1_r1),
    kInstruction_mvn_cs_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r2_r2),
    kInstruction_mvn_cs_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r3_r3),
    kInstruction_mvn_cs_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r4_r4),
    kInstruction_mvn_cs_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r5_r5),
    kInstruction_mvn_cs_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r6_r6),
    kInstruction_mvn_cs_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cs_r7_r7),
    kInstruction_mvn_cs_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r0_r0),
    kInstruction_mvn_cc_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r1_r1),
    kInstruction_mvn_cc_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r2_r2),
    kInstruction_mvn_cc_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r3_r3),
    kInstruction_mvn_cc_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r4_r4),
    kInstruction_mvn_cc_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r5_r5),
    kInstruction_mvn_cc_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r6_r6),
    kInstruction_mvn_cc_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_cc_r7_r7),
    kInstruction_mvn_cc_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r0_r0),
    kInstruction_mvn_mi_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r1_r1),
    kInstruction_mvn_mi_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r2_r2),
    kInstruction_mvn_mi_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r3_r3),
    kInstruction_mvn_mi_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r4_r4),
    kInstruction_mvn_mi_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r5_r5),
    kInstruction_mvn_mi_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r6_r6),
    kInstruction_mvn_mi_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_mi_r7_r7),
    kInstruction_mvn_mi_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r0_r0),
    kInstruction_mvn_pl_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r1_r1),
    kInstruction_mvn_pl_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r2_r2),
    kInstruction_mvn_pl_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r3_r3),
    kInstruction_mvn_pl_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r4_r4),
    kInstruction_mvn_pl_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r5_r5),
    kInstruction_mvn_pl_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r6_r6),
    kInstruction_mvn_pl_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_pl_r7_r7),
    kInstruction_mvn_pl_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r0_r0),
    kInstruction_mvn_vs_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r1_r1),
    kInstruction_mvn_vs_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r2_r2),
    kInstruction_mvn_vs_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r3_r3),
    kInstruction_mvn_vs_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r4_r4),
    kInstruction_mvn_vs_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r5_r5),
    kInstruction_mvn_vs_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r6_r6),
    kInstruction_mvn_vs_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vs_r7_r7),
    kInstruction_mvn_vs_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r0_r0),
    kInstruction_mvn_vc_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r1_r1),
    kInstruction_mvn_vc_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r2_r2),
    kInstruction_mvn_vc_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r3_r3),
    kInstruction_mvn_vc_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r4_r4),
    kInstruction_mvn_vc_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r5_r5),
    kInstruction_mvn_vc_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r6_r6),
    kInstruction_mvn_vc_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_vc_r7_r7),
    kInstruction_mvn_vc_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r0_r0),
    kInstruction_mvn_hi_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r1_r1),
    kInstruction_mvn_hi_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r2_r2),
    kInstruction_mvn_hi_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r3_r3),
    kInstruction_mvn_hi_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r4_r4),
    kInstruction_mvn_hi_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r5_r5),
    kInstruction_mvn_hi_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r6_r6),
    kInstruction_mvn_hi_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_hi_r7_r7),
    kInstruction_mvn_hi_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r0_r0),
    kInstruction_mvn_ls_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r1_r1),
    kInstruction_mvn_ls_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r2_r2),
    kInstruction_mvn_ls_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r3_r3),
    kInstruction_mvn_ls_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r4_r4),
    kInstruction_mvn_ls_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r5_r5),
    kInstruction_mvn_ls_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r6_r6),
    kInstruction_mvn_ls_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ls_r7_r7),
    kInstruction_mvn_ls_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r0_r0),
    kInstruction_mvn_ge_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r1_r1),
    kInstruction_mvn_ge_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r2_r2),
    kInstruction_mvn_ge_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r3_r3),
    kInstruction_mvn_ge_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r4_r4),
    kInstruction_mvn_ge_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r5_r5),
    kInstruction_mvn_ge_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r6_r6),
    kInstruction_mvn_ge_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_ge_r7_r7),
    kInstruction_mvn_ge_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r0_r0),
    kInstruction_mvn_lt_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r1_r1),
    kInstruction_mvn_lt_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r2_r2),
    kInstruction_mvn_lt_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r3_r3),
    kInstruction_mvn_lt_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r4_r4),
    kInstruction_mvn_lt_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r5_r5),
    kInstruction_mvn_lt_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r6_r6),
    kInstruction_mvn_lt_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_lt_r7_r7),
    kInstruction_mvn_lt_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r0_r0),
    kInstruction_mvn_gt_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r1_r1),
    kInstruction_mvn_gt_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r2_r2),
    kInstruction_mvn_gt_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r3_r3),
    kInstruction_mvn_gt_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r4_r4),
    kInstruction_mvn_gt_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r5_r5),
    kInstruction_mvn_gt_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r6_r6),
    kInstruction_mvn_gt_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_gt_r7_r7),
    kInstruction_mvn_gt_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r0_r0),
    kInstruction_mvn_le_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r1_r1),
    kInstruction_mvn_le_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r2_r2),
    kInstruction_mvn_le_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r3_r3),
    kInstruction_mvn_le_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r4_r4),
    kInstruction_mvn_le_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r5_r5),
    kInstruction_mvn_le_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r6_r6),
    kInstruction_mvn_le_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_mvn_le_r7_r7),
    kInstruction_mvn_le_r7_r7,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_RN_IDENTICAL_LOW_REGISTERS_IN_IT_BLOCK_MVN_T32_H_
